.font-weight-normal {
    font-weight: normal;
}

#results_wrapper {
    /* display the horizontal scroll when we resize columns */
    overflow-x: auto;
}

#results_wrapper > .row {
    /* no gutter on bootstrap rows */
    margin-right: 0;
    margin-left: 0;
}

#results_wrapper > .row > [class*="col-"] {
    padding-right: 0;
    padding-left: 0;
}

.popover-content {
    word-break: break-all;
}

#results {
    /* the layout needs to be fixed for percentages to work */
    table-layout: fixed;
    width: 100%;
}

#results td > div {
    /* otherwise divs won't respect the overflow property */
    display: initial;
}

#results td {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

#results td:last-child div {
    /* side by side icons in the Debug column */
    display: inline-block;
}

#results th {
    /* needed to position the resizer */
    position: relative;
}

#results th > .resizer {
    position: absolute;
    right: 0;
    top: 0;
    cursor: col-resize;
    width: 8px;
}

/* Basic metadata for svg */
.icon {
    width: 22px;
    height: 22px;
    background-repeat: no-repeat;
    display: block;
}

.icon.icon-logs {
    background-image: url("data:image/svg+xml;base64,{{ data.logs_icon|safe }}");
}

.icon.icon-whiteboard {
    background-image: url("data:image/svg+xml;base64,{{ data.whiteboard_icon|safe }}");
}
